@@ -188,7 +188,7 @@ config = {
 
 			"err": {"type": "text",  "analyzer": "err_ana"},
 			"fd": { "type": "keyword"},
-			"short_msg": { "type": "keyword"},
+			"short_msg": { "type": "keyword", "index": "false"},
 			"arr": { "type": "keyword", "index": "false" }, # dim arr of dsk
 			"info": { "type": "keyword", "index": "false" ,"store": "false"},
 			"kw": { "type": "keyword", "index": "false" ,"store": "false", "ignore_above": 60},
